@@ -1,4 +1,16 @@
-( cd bin ; rm -rf dnsdomainname )
+cd etc-incoming
+for file in * */* ; do
+ if [ ! -d file ]; then # file is not a directory
+  if [ ! -r ../etc/$file ]; then # file isn't already in /etc, so copy it.
+   cp -a $file ../etc/$file
+  fi
+ fi
+done
+cd ..
+rm -rf etc-incoming
+#( cd sbin ; rm -rf netconfig )
+#( cd sbin ; ln -sf netconfig.color netconfig )
+( cd bin ; rm -rf dnsdomainame )
 ( cd bin ; ln -sf hostname dnsdomainname )
 ( cd bin ; rm -rf ypdomainname )
 ( cd bin ; ln -sf hostname ypdomainname )
@@ -6,16 +18,17 @@
 ( cd bin ; ln -sf hostname nisdomainname )
 ( cd bin ; rm -rf domainname )
 ( cd bin ; ln -sf hostname domainname )
-( cd etc/rc.d ; rm -rf rc.inet1 )
-( cd etc/rc.d ; ln -sf rc.inet1.tradnet rc.inet1 )
-# ( cd usr/bin ; rm -rf pftp )
-# ( cd usr/bin ; ln -sf ftp pftp )
+#
+( cd usr/bin ; rm -rf pftp )
+( cd usr/bin ; ln -sf ftp pftp )
+( cd usr/share/man/man1 ; rm -rf pftp.1.gz )
+( cd usr/share/man/man1 ; ln -sf ftp.1.gz pftp.1.gz )
 ( cd usr/share/man/man8 ; rm -rf writed.8.gz )
 ( cd usr/share/man/man8 ; ln -sf in.writed.8.gz writed.8.gz )
-( cd usr/share/man/man8 ; rm -rf rwalld.8.gz )
-( cd usr/share/man/man8 ; ln -sf rpc.rwalld.8.gz rwalld.8.gz )
 ( cd usr/share/man/man8 ; rm -rf bootparamd.8.gz )
 ( cd usr/share/man/man8 ; ln -sf rpc.bootparamd.8.gz bootparamd.8.gz )
+( cd usr/share/man/man8 ; rm -rf rwalld.8.gz )
+( cd usr/share/man/man8 ; ln -sf rpc.rwalld.8.gz rwalld.8.gz )
 ( cd usr/share/man/man8 ; rm -rf talkd.8.gz )
 ( cd usr/share/man/man8 ; ln -sf in.talkd.8.gz talkd.8.gz )
 ( cd usr/share/man/man8 ; rm -rf rexecd.8.gz )
@@ -26,26 +39,27 @@
 ( cd usr/share/man/man8 ; ln -sf in.telnetd.8.gz telnetd.8.gz )
 ( cd usr/share/man/man8 ; rm -rf nalkd.8.gz )
 ( cd usr/share/man/man8 ; ln -sf in.talkd.8.gz nalkd.8.gz )
+( cd usr/share/man/man8 ; rm -rf rpc.mountd.8.gz )
+( cd usr/share/man/man8 ; ln -sf mountd.8.gz rpc.mountd.8.gz )
 ( cd usr/share/man/man8 ; rm -rf fingerd.8.gz )
 ( cd usr/share/man/man8 ; ln -sf in.fingerd.8.gz fingerd.8.gz )
 ( cd usr/share/man/man8 ; rm -rf rlogind.8.gz )
 ( cd usr/share/man/man8 ; ln -sf in.rlogind.8.gz rlogind.8.gz )
 ( cd usr/share/man/man8 ; rm -rf comsat.8.gz )
 ( cd usr/share/man/man8 ; ln -sf in.comsat.8.gz comsat.8.gz )
-# ( cd usr/share/man/man1 ; rm -rf pftp.1.gz )
-# ( cd usr/share/man/man1 ; ln -sf ftp.1.gz pftp.1.gz )
+( cd usr/share/man/man8 ; rm -rf rpc.nfsd.8.gz )
+( cd usr/share/man/man8 ; ln -sf nfsd.8.gz rpc.nfsd.8.gz )
+( cd usr/share/man/man8 ; rm -rf rpc.lockd.8.gz )
+( cd usr/share/man/man8 ; ln -sf lockd.8.gz rpc.lockd.8.gz )
 ( cd usr/sbin ; rm -rf in.talkd )
 ( cd usr/sbin ; ln -sf in.ntalkd in.talkd )
 ( cd usr/sbin ; rm -rf netconfig )
 ( cd usr/sbin ; ln -sf netconfig.tradnet netconfig )
 ( cd usr/sbin ; rm -rf enetconfig )
-( cd usr/sbin ; ln -sf enetconfig.tradnet enetconfig )
-cd etc-incoming
-for file in *  ; do
-  if [ -r ../etc/$file ]; then # backup old file
-     mv ../etc/$file ../etc/$file.old
-  fi
-  mv $file ../etc/$file
-done
-cd ..
-rm -rf etc-incoming
+( cd usr/sbin ; ln -sf enetconfig.tradnet enetconfig )       
+( cd etc/rc.d ; rm -rf rc.inet1 )
+( cd etc/rc.d ; ln -sf rc.inet1.tradnet rc.inet1 )
+( cd usr/lib ; rm -rf libwrap.so )
+( cd usr/lib ; ln -sf ../../lib/libwrap.so.0 libwrap.so )
+( cd lib ; rm -rf libwrap.so.0 )
+( cd lib ; ln -sf libwrap.so.0.7.6 libwrap.so.0 )
